pub enum GenericArgument {
TypeParameter(Type),
Lifetime(GenericLifetimeParameter),
Const(ConstGenericArgument),
}Expand description
A single generic argument supplied to a generic type or function.
Variants
TypeParameter(Type)
A generic type parameter, e.g. u32 in Vec<u32> or T in HashSet<T>.
Lifetime(GenericLifetimeParameter)
A lifetime parameter, e.g. 'a in Cow<'a, str>.
Const(ConstGenericArgument)
A const generic argument with a concrete evaluated value, e.g. 8 in Size<8>.
Implementations
Sourceimpl GenericArgument
impl GenericArgument
Sourcepub fn render_type_into(
&self,
id2name: &BiHashMap<PackageId, String>,
buffer: &mut String,
)
pub fn render_type_into( &self, id2name: &BiHashMap<PackageId, String>, buffer: &mut String, )
Render this generic argument preserving named lifetimes as-is.
Sourcepub fn render_with_inferred_lifetimes_into(
&self,
id2name: &BiHashMap<PackageId, String>,
buffer: &mut String,
)
pub fn render_with_inferred_lifetimes_into( &self, id2name: &BiHashMap<PackageId, String>, buffer: &mut String, )
Render this generic argument, replacing named lifetimes with '_.
Sourcepub fn display_for_error_into<W: Write>(&self, buffer: &mut W)
pub fn display_for_error_into<W: Write>(&self, buffer: &mut W)
Render this generic argument for error messages.